# BrewBlox CLI management tool

The primary tool for installing and managing BrewBlox. Uses Click.

Install-specific commands are defined in [brewblox-ctl-lib](https://github.com/BrewBlox/brewblox-ctl-lib).

Wraps multiple docker-compose commands to provide a one-stop tool.

Provides the `http` CLI utility tool as a more specific and less cryptic alternative to `curl`.
